<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Team\Models\Team;
use EventPortal\Tests\Support\Traits\InteractsWithTeams;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\TestResponse;
use Spatie\Snapshots\MatchesSnapshots;

class TeamIndexTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots, InteractsWithTeams, SeedRolesAndPermissions;

    /** @test **/
    public function admins_who_are_in_a_team_can_view_index_and_not_see_other_teams(): void
    {
        factory(Team::class)->create(['name' => 'SHOULD NOT SEE']);
        $adminTeam = factory(Team::class)->create(['name' => 'SHOULD SEE']);
        $admin = factory(Admin::class)->state('admin')->create();

        $this->addToSameTeam([$admin], $adminTeam);

        $this->actingAsAdmin($admin);
        $response = $this->get(route('admin.team.index'));

        $this->assertEquals(1, $this->countOccurrences($response, 'SHOULD SEE'));
        $this->assertEquals(0, $this->countOccurrences($response, 'SHOULD NOT SEE'));
        $this->assertMatchesJsonSnapshot($response->props());
    }

    /** @test **/
    public function super_admins_who_are_in_a_team_can_view_index_and_see_all_teams(): void
    {
        factory(Team::class)->create(['name' => 'SHOULD SEE']);
        $superAdminTeam = factory(Team::class)->create(['name' => 'SHOULD SEE']);
        $superAdmin = factory(Admin::class)->state('super-admin')->create();

        $this->addToSameTeam([$superAdmin], $superAdminTeam);

        $this->actingAsSuperAdmin($superAdmin);

        $response = $this->get(route('admin.team.index'));
        $this->assertEquals(2, $this->countOccurrences($response, 'SHOULD SEE'));

        $this->assertMatchesJsonSnapshot($response->props());
    }

    private function countOccurrences(TestResponse $response, string $needle): int
    {
        return substr_count(json_encode($response->props('data.data')), $needle);
    }
}
