<?php

namespace EventPortal\Tests\Unit\Models;

use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class PathwayTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_create_for_agenda()
    {
        $event = factory(Event::class)->create();
        $agenda = factory(Agenda::class)->create();

        $pathway = Pathway::generate(
            $event,
            Pathway::DEFAULT,
            'Lorem ipsum dolor sit amet, consectetur adipiscing elit. In eget quam enim.'
        );
        $agenda->pathways()->attach($pathway->id);


        $this
            ->assertHasPathway($agenda, $pathway)
            ->assertDatabaseHas('pathways', [
                'name' => 'Default',
                'description' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. In eget quam enim.',
            ]);
    }

    /** @test **/
    public function can_create_for_form(): void
    {
        $event = factory(Event::class)->create();
        $form = factory(Form::class)->create();

        $pathway = Pathway::generate(
            $event,
            Pathway::DEFAULT,
            'Lorem ipsum dolor sit amet, consectetur adipiscing elit. In eget quam enim.'
        );

        $form->pathways()->attach($pathway->id);

        $this
            ->assertHasPathway($form, $pathway)
            ->assertDatabaseHas('pathways', [
                'name' => 'Default',
                'description' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. In eget quam enim.',
            ]);
    }
}
